drop _all
capture log close
#delimit;
set more 1;
set memory 750m;
set matsize 400;


log using table4, replace text;

*THIS FILE ESTIMATES THE INVERSE ELASTICITY OF SUBSTITUTION FOR NATIVES AND IMMIGRANTS USING A PREFERRED SPECIFICATION;
*18-64, POSITIVE HOURS WORKED, CORRECT DEFINITION OF IMMIGRANTS, EDUCREC FOR EDUCATION, ADJUST FOR TOP CODING;
*ESTIMATE EITHER MEN ONLY OR MEN AND WOMEN AND WITH INCWAGE;


use "C:\Istata\PUMS\GRGR\Peri\Ipums\ipums60.dta",	clear;

generate byte imm=(bpld>=15000);
replace imm=0 if bpld==90011 | bpld==90021;
drop if wkswork2==0;

generate hours=7.5*(hrswork2==1) + 22*(hrswork2==2) + 32*(hrswork2==3) + 37*(hrswork2==4) + 40*(hrswork2==5) + 44.5*(hrswork2==6) 
	+ 54*(hrswork2==7) + 70*(hrswork2==8) ;
generate weeks=6.5*(wkswork2==1) + 20*(wkswork2==2) + 33*(wkswork2==3) + 43.5*(wkswork2==4) + 48.5*(wkswork2==5) + 51*(wkswork2==6) ;

generate pdeflator=4.75;
drop if incwage==0 | incwage==999999;
replace incwage=25000*1.5 if incwage==25000;
replace incbusfm=25000*1.5 if incbusfm==25000;
gen incearn=incwage+incbusfm;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

generate survey=1960;
sort survey edcode expcode;
save rep60.dta, replace;



use	"C:\Istata\PUMS\GRGR\Peri\Ipums\ipums70.dta",	clear;

generate school=higraded - (int(higraded/10))*10;
generate byte imm=(citizen==2 | citizen==3);
drop if wkswork2==0;

generate hours=7.5*(hrswork2==1) + 22*(hrswork2==2) + 32*(hrswork2==3) + 37*(hrswork2==4) + 40*(hrswork2==5) + 44.5*(hrswork2==6) 
	+ 54*(hrswork2==7) + 70*(hrswork2==8) ;
generate weeks=6.5*(wkswork2==1) + 20*(wkswork2==2) + 33*(wkswork2==3) + 43.5*(wkswork2==4) + 48.5*(wkswork2==5) + 51*(wkswork2==6) ;

generate pdeflator=3.63;
drop if incwage==0 | incwage==999999;
replace incwage=50000*1.5 if incwage==50000;
replace incbus=50000*1.5 if incbus==50000;
replace incfarm=50000*1.5 if incfarm==50000;
gen incearn=incwage+incbus+incfarm;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

generate survey=1970;
sort survey edcode expcode;
save rep70.dta, replace;



use	"C:\Istata\PUMS\GRGR\Peri\Ipums\ipums80.dta",	clear;

generate byte imm=(citizen==2 | citizen==3);
drop if wkswork1==0;

generate pdeflator=1.85;
drop if incwage==0 | incwage==999999;
replace incwage=75000*1.5 if incwage==75000;
replace incbus=75000*1.5 if incbus==75000;
replace incfarm=75000*1.5 if incfarm==75000;
gen incearn=incwage+incbus+incfarm;

generate weeks=wkswork1;
generate hours=uhrswork;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

generate survey=1980;
sort survey edcode expcode;
save rep80.dta, replace;



use	"C:\Istata\PUMS\GRGR\Peri\Ipums\ipums90.dta",	clear;

generate byte imm=(citizen==2 | citizen==3);
drop if wkswork1==0;

generate pdeflator=1.22;
drop if incwage==0 | incwage==999999;
generate weeks=wkswork1;
generate hours=uhrswork;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

generate survey=1990;
sort survey edcode expcode;
save rep90, replace;



use	"C:\Istata\PUMS\GRGR\Peri\Ipums\ipums00.dta",	clear;

generate byte imm=(citizen==2 | citizen==3);
drop if wkswork1==0;

generate pdeflator=1;
drop if incwage==0 | incwage==999999;
generate weeks=wkswork1;
generate hours=uhrswork;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

generate survey=2000;
sort survey edcode expcode;
save rep00.dta, replace;



use	"C:\Istata\PUMS\GRGR\Peri\Ipums\acs06.dta";

generate survey=2000+year;
keep if survey==2006;

generate byte imm=(citizen==2 | citizen==3);
drop if wkswork1==0;

generate pdeflator=0.85;
drop if incwage==0 | incwage==999999;
generate weeks=wkswork1;
generate hours=uhrswork;

* DEFINE SAMPLE RESTRICTIONS, COMMON VARIABLES;
do table4_restriction;

gen survey=2006;
sort survey edcode expcode;
save rep06.dta, replace;




*POOL DATA ACROSS YEARS;
use rep60.dta, clear;
append using rep70.dta;
append using rep80.dta;
append using rep90.dta;
append using rep00.dta;
append using rep06.dta;

reshape wide sumweight lweekly weekly sizew slweekly sweekly, i(survey edcode expcode) j(imm);

for any sumweight lweekly weekly sizew slweekly sweekly : ren X0 Xn;
for any sumweight lweekly weekly sizew slweekly sweekly : ren X1 Xi;

*MERGE IN DATA ON COUNTS BASED ON HOURS WORKED;
sort survey edcode expcode;
merge survey edcode expcode using table4_count;
tab _merge; drop _merge;
sort survey edcode expcode;
merge survey edcode expcode using table4_pop;
tab _merge; drop _merge;
save table4.dta, replace;

use table4;

gen code1=survey*10 + edcode;
gen code2=survey*100 + expcode;
gen code3=expcode*10 + edcode;
tab edcode, gen(educ);
tab survey, gen(year);
tab expcode, gen(xp);
tab code1, gen(inter);
tab code2, gen(intra);
tab code3, gen(extra);

*DEFINE QUANTITES BASED ON COUNTS OF WORKERS USING HOURS WORKED;
gen lmrelm=log(immigm/nativem);
gen lmrelf=log((immig-immigm)/(native-nativem));
gen lmrlmf=log(immig/native);
gen lmpm=log(pimmigm/pnativem);
gen lmpf=log(pimmig-pimmigm)-log(pnative-pnativem);
gen lmpmf=log(pimmig/pnative);

gen logrelweek1=lweeklyi-lweeklyn;

generate sizew=sizewn+sizewi;
generate varweight1=(slweeklyn^2/sizewn) + (slweeklyi^2/sizewi);
replace varweight1=1/varweight1;

*INVERSE VARIANCE OF DEP. VARIABLE WEIGHTS;
*DEP. VARIABLE IS MEAN LOG WEEKLY EARNINGS;
*WLS ESTIMATES;
*COUNTS OF MALES FOR REGRESSOR;
quietly xi: reg logrelweek1 lmrelm i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl a nocon lmrelm, WLS males;
*COUNTS OF FEMALES FOR REGRESSOR;
quietly xi: reg logrelweek1 lmrelf i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl b nocon lmrelf, WLS females;
*COUNTS OF MALES+FEMALES REGRESSOR;
quietly xi: reg logrelweek1 lmrlmf i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl c nocon lmrlmf, WLS males+females;
*IV ESTIMATES;
*COUNTS OF MALES FOR REGRESSOR;
quietly xi: ivreg logrelweek1 (lmrelm=lmpm) i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl d nocon lmrelm, IV males;
*COUNTS OF FEMALES FOR REGRESSOR;
quietly xi: ivreg logrelweek1 (lmrelf=lmpf) i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl e nocon lmrelf, IV females;
*COUNTS OF MALES+FEMALES REGRESSOR;
quietly xi: ivreg logrelweek1 (lmrlmf=lmpmf) i.survey*i.edcode i.survey*i.expcode i.edcode*i.expcode [aw=varweight1] if survey<=2000 | survey==2006, cluster(code3);
	modl f nocon lmrlmf, IV males+females;
modltbl se (4) a b c d e f ;

log close;

for any 60 70 80 90 00 06 : erase repX.dta;
